import simplex


def main():
    simplex.dsimplex()
